+++
title = "Replace \"description\" with \"summary\""
summary = """
  This should be rendered as `.Summary` in Hugo v0.55+. For only Hugo
  versions, this will front-matter can be retrieved only as
  `.Params.summary`.
  """
tags = ["front-matter", "keys", "replace", "description", "summary"]
draft = false
+++

This text will be in the post body.
